@@ -4,10 +4,6 @@ pub fn keypath() -> String {
     env::var("KEYPATH").unwrap()
 }
 
-pub fn psql_params() -> String {
-    env::var("PSQL_PARAMS").unwrap()
-}
-
 pub fn rpc_endpoint() -> String {
     env::var("RPC_ENDPOINT").unwrap()
 }
